hstrat
======

.. automodule:: hstrat

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   hstrat.helpers
   hstrat.hstrat
   hstrat.test

